Variables
=========

Variables are viewed and edited in the GUI almost exactly the same as data, as
shown in Figure.
An important exception is that, since there are only v1 variables arrays and no
v2 arrays of v1 arrays, the variable creation window only has one pane, and
separate v1 arrays created in different tabs of the window are completely
independent.

Also, the user can clone an existing v1 array with the drop down menu below the
"Duplicate" button.

The variable viewing and editing windows in the GUI.


.. figure:: /_static/gui/figures/variables_1.png
   :align: center
   :alt: View and edit global variables with the Global Parameters window.

   Accessing the v1 variable window from the root window (console hidden).


.. figure:: /_static/gui/figures/variables_2.png
   :align: center
   :alt: View and edit global variables with the Global Parameters window.

   The v1 variable window, showing the currently defined v1 variable arrays.

.. figure:: /_static/gui/figures/variables_3.png
   :align: center
   :alt: View and edit global variables with the Global Parameters window.

   The bulk fill window for quad_k1.

.. figure:: /_static/gui/figures/variables_4.png
   :align: center
   :alt: View and edit global variables with the Global Parameters window.

   The variable window for quad_k1, displaying each of its variables and their key attributes.

.. figure:: /_static/gui/figures/variables_5.png
   :align: center
   :alt: View and edit global variables with the Global Parameters window.

   The individual variable window for quad_k1[5], showing all of its settings and allowing the user to edit some of them.

.. figure:: /_static/gui/figures/variables_6.png
   :align: center
   :alt: View and edit global variables with the Global Parameters window.

   The variable array creation window.
